@@ -1,3 +1,4 @@
+-- | How to name the debian packages based on the cabal package name and version number.
 {-# LANGUAGE FlexibleInstances, MultiParamTypeClasses, OverloadedStrings, RankNTypes, ScopedTypeVariables, StandaloneDeriving, TypeFamilies #-}
 {-# OPTIONS -Wall -Wwarn -fno-warn-name-shadowing -fno-warn-orphans #-}
 module Debian.Debianize.DebianName
@@ -7,25 +8,27 @@ module Debian.Debianize.DebianName
     , mkPkgName'
     , mapCabal
     , splitCabal
+    , remapCabal
     ) where
 
+
 import Control.Applicative ((<$>))
+import Control.Lens
 import Data.Char (toLower)
-import Data.Lens.Lazy (access)
-import Data.Map as Map (lookup, alter)
-import Data.Version (Version, showVersion)
-import Debian.Debianize.Types.BinaryDebDescription as Debian (PackageType(..))
-import Debian.Debianize.Types.Atoms as T (debianNameMap, packageDescription, utilsPackageNameBase)
-import Debian.Debianize.Monad (DebT)
-import Debian.Debianize.Prelude ((%=))
-import Debian.Debianize.VersionSplits (DebBase(DebBase, unDebBase), insertSplit, doSplits, VersionSplits, makePackage)
+import Data.Map as Map (alter, lookup)
+import Data.Version (showVersion, Version)
+import Debian.Debianize.Monad (CabalT)
+import Debian.Debianize.CabalInfo as A (debianNameMap, packageDescription, debInfo)
+import Debian.Debianize.BinaryDebDescription as Debian (PackageType(..))
+import Debian.Debianize.DebInfo as D (overrideDebianNameBase, utilsPackageNameBase)
+import Debian.Debianize.VersionSplits (DebBase(DebBase, unDebBase), doSplits, insertSplit, makePackage, VersionSplits)
 import Debian.Orphans ()
 import Debian.Relation (PkgName(..), Relations)
 import qualified Debian.Relation as D (VersionReq(EEQ))
 import Debian.Version (parseDebianVersion)
 import Distribution.Compiler (CompilerFlavor(..))
 import Distribution.Package (Dependency(..), PackageIdentifier(..), PackageName(PackageName))
-import qualified Distribution.PackageDescription as Cabal
+import qualified Distribution.PackageDescription as Cabal (PackageDescription(package))
 import Prelude hiding (unlines)
 
 data Dependency_
@@ -36,12 +39,12 @@ data Dependency_
     deriving (Eq, Show)
 
 -- | Build the Debian package name for a given package type.
-debianName :: (Monad m, Functor m, PkgName name) => PackageType -> CompilerFlavor -> DebT m name
+debianName :: (Monad m, Functor m, PkgName name) => PackageType -> CompilerFlavor -> CabalT m name
 debianName typ cfl =
     do base <-
            case (typ, cfl) of
-             (Utilities, GHC) -> access utilsPackageNameBase >>= maybe (((\ base -> "haskell-" ++ base ++ "-utils") . unDebBase) <$> debianNameBase) return
-             (Utilities, _) -> access utilsPackageNameBase >>= maybe (((\ base -> base ++ "-utils") . unDebBase) <$> debianNameBase) return
+             (Utilities, GHC) -> use (debInfo . utilsPackageNameBase) >>= maybe (((\ base -> "haskell-" ++ base ++ "-utils") . unDebBase) <$> debianNameBase) return
+             (Utilities, _) -> use (debInfo . utilsPackageNameBase) >>= maybe (((\ base -> base ++ "-utils") . unDebBase) <$> debianNameBase) return
              _ -> unDebBase <$> debianNameBase
        return $ mkPkgName' cfl typ (DebBase base)
 
@@ -49,16 +52,18 @@ debianName typ cfl =
 -- names based on version numbers.  If a version split happens at v,
 -- this will return the ltName if < v, and the geName if the relation
 -- is >= v.
-debianNameBase :: Monad m => DebT m DebBase
+debianNameBase :: Monad m => CabalT m DebBase
 debianNameBase =
-    do Just pkgDesc <- access packageDescription
+    do nameBase <- use (debInfo . D.overrideDebianNameBase)
+       pkgDesc <- use packageDescription
        let pkgId = Cabal.package pkgDesc
-       nameMap <- access T.debianNameMap
+       nameMap <- use A.debianNameMap
        let pname@(PackageName _) = pkgName pkgId
            version = (Just (D.EEQ (parseDebianVersion (showVersion (pkgVersion pkgId)))))
-       case Map.lookup (pkgName pkgId) nameMap of
-         Nothing -> return $ debianBaseName pname
-         Just splits -> return $ doSplits splits version
+       case (nameBase, Map.lookup (pkgName pkgId) nameMap) of
+         (Just base, _) -> return base
+         (Nothing, Nothing) -> return $ debianBaseName pname
+         (Nothing, Just splits) -> return $ doSplits splits version
 
 -- | Build a debian package name from a cabal package name and a
 -- debian package type.  Unfortunately, this does not enforce the
@@ -96,7 +101,7 @@ debianBaseName (PackageName name) =
 -- Not really a debian package name, but the name of a cabal package
 -- that maps to the debian package name we want.  (Should this be a
 -- SrcPkgName?)
-mapCabal :: Monad m => PackageName -> DebBase -> DebT m ()
+mapCabal :: Monad m => PackageName -> DebBase -> CabalT m ()
 mapCabal pname dname =
     debianNameMap %= Map.alter f pname
     where
@@ -105,10 +110,18 @@ mapCabal pname dname =
       f (Just sp) = error $ "mapCabal " ++ show pname ++ " " ++ show dname ++ ": - already mapped: " ++ show sp
 
 -- | Map versions less than ver of Cabal Package pname to Debian package ltname
-splitCabal :: Monad m => PackageName -> DebBase -> Version -> DebT m ()
+splitCabal :: Monad m => PackageName -> DebBase -> Version -> CabalT m ()
 splitCabal pname ltname ver =
     debianNameMap %= Map.alter f pname
     where
       f :: Maybe VersionSplits -> Maybe VersionSplits
       f Nothing = error $ "splitCabal - not mapped: " ++ show pname
       f (Just sp) = Just (insertSplit ver ltname sp)
+
+-- | Replace any existing mapping of the cabal name 'pname' with the
+-- debian name 'dname'.  (Use case: to change the debian package name
+-- so it differs from the package provided by ghc.)
+remapCabal :: Monad m => PackageName -> DebBase -> CabalT m ()
+remapCabal pname dname = do
+  debianNameMap %= Map.alter (const Nothing) pname
+  mapCabal pname dname
