@@ -25,17 +25,19 @@ debianDefaults =
     do -- These are the two epoch names I know about in the debian repo
        A.epochMap %= Map.insert (PackageName "HaXml") 1
        A.epochMap %= Map.insert (PackageName "HTTP") 1
-       -- The hsx2hs build tool is in an an eponymous deb
-       (A.debInfo . D.execMap) %= Map.insert "hsx2hs" [[Rel (BinPkgName "hsx2hs") Nothing Nothing]]
+       -- Associate some build tools and their corresponding
+       -- (eponymous) debian package names
+       mapM (\name -> (A.debInfo . D.execMap) %= Map.insert name [[Rel (BinPkgName name) Nothing Nothing]])
+            ["ghc", "happy", "alex", "hsx2hs"]
        -- The parsec debs are suffixed with either "2" or "3"
        mapCabal (PackageName "parsec") (DebBase "parsec3")
-       splitCabal (PackageName "parsec") (DebBase "parsec2") (Version [3] [])
        -- Similar split for quickcheck
        mapCabal (PackageName "QuickCheck") (DebBase "quickcheck2")
-       splitCabal (PackageName "QuickCheck") (DebBase "quickcheck1") (Version [2] [])
        -- Something was required for this package at one time - it
        -- looks like a no-op now
        mapCabal (PackageName "gtk2hs-buildtools") (DebBase "gtk2hs-buildtools")
        -- Upgrade transformers to 0.4 - no don't!
        -- remapCabal (PackageName "transformers") (DebBase "transformers4")
        -- remapCabal (PackageName "haskeline") (DebBase "haskeline0713")
+       mapCabal (PackageName "haskell-src-exts") (DebBase "src-exts")
+       mapCabal (PackageName "haskell-src-meta") (DebBase "src-meta")
