@@ -23,7 +23,7 @@ import Debian.Control.Common ()
 import qualified Debian.Debianize.DebInfo as D (Atom(Install, InstallDir, Link), atomSet, changelog, compat, control, copyright, installInit, intermediateFiles, logrotateStanza, postInst, postRm, preInst, preRm, rulesFragments, rulesHead, rulesIncludes, rulesSettings, sourceFormat, watch)
 import Debian.Debianize.Monad (DebianT)
 import Debian.Debianize.Prelude (escapeDebianWildcards, showDeps')
-import qualified Debian.Debianize.BinaryDebDescription as B (architecture, BinaryDebDescription, binaryPriority, binarySection, breaks, builtUsing, conflicts, depends, description, essential, package, PackageRelations, preDepends, provides, recommends, relations, replaces, suggests)
+import qualified Debian.Debianize.BinaryDebDescription as B (architecture, BinaryDebDescription, binaryPriority, multiArch, binarySection, breaks, builtUsing, conflicts, depends, description, essential, package, PackageRelations, preDepends, provides, recommends, relations, replaces, suggests)
 import Debian.Debianize.CopyrightDescription (CopyrightDescription)
 import qualified Debian.Debianize.SourceDebDescription as S (binaryPackages, buildConflicts, buildConflictsIndep, buildDepends, buildDependsIndep, dmUploadAllowed, homepage, maintainer, priority, section, source, SourceDebDescription, standardsVersion, uploaders, vcsFields, VersionControlSpec(VCSArch, VCSBrowser, VCSBzr, VCSCvs, VCSDarcs, VCSGit, VCSHg, VCSMtn, VCSSvn), xDescription, XField(XField), XFieldDest(B, C, S), xFields)
 import Debian.Policy (maintainerOfLastResort)
@@ -200,6 +200,7 @@ controlFile src =
           Paragraph
            ([Field ("Package", " " ++ (show . ppPrint . view B.package $ bin)),
              Field ("Architecture", " " ++ (show . maybe empty ppPrint . view B.architecture $ bin))] ++
+            mField "Multi-Arch" (view B.multiArch bin) ++
             mField "Section" (view B.binarySection bin) ++
             mField "Priority" (view B.binaryPriority bin) ++
             mField "Essential" (view B.essential bin) ++
