@@ -513,6 +513,8 @@ buildOnlyTestsP = O.flag TestsRun TestsBuild m where
 flagsP :: O.Parser Flags
 flagsP = Flags <$> verbosityP
                <*> dryRunP
+               <*> upgradeP
+               <*> roundtripP
                <*> pure False     -- validate
                <*> ghcjsP         -- CompilerFlavor
                <*> (flagSet <$> cabalFlagsP)    -- cabalFlagAssignments
@@ -540,6 +542,23 @@ dryRunP = O.switch m where
     "to the one we would generate."
     ]
 
+upgradeP :: O.Parser Bool
+upgradeP = O.switch m where
+  m = O.help helpMsg
+      <> O.long "upgrade"
+  helpMsg = unlines [
+    "Upgrade an existing debianization carefully",
+    "preserving fields that are commonly hand-edited."
+    ]
+
+roundtripP :: O.Parser Bool
+roundtripP = O.switch m where
+  m = O.help helpMsg
+      <> O.long "roundtrip"
+  helpMsg = unlines [
+    "Roundtrip a debianization to normalize it."
+    ]
+
 ghcjsP :: O.Parser CompilerFlavor
 ghcjsP = O.flag GHC
 #if MIN_VERSION_Cabal(1,22,0)
