@@ -9,23 +9,35 @@ module Debian.GHC
     -- , ghcNewestAvailableVersion'
     -- , ghcNewestAvailableVersion
     -- , compilerIdFromDebianVersion
+    , compilerPackageName
+#if MIN_VERSION_Cabal(1,22,0)
+    , getCompilerInfo
+#endif
     ) where
 
 import Control.DeepSeq (force)
 import Control.Exception (SomeException, try)
 import Control.Monad (when)
-import Data.Char (toLower, toUpper, isSpace)
+import Control.Monad.Trans (MonadIO, liftIO)
+import Data.Char ({-isSpace, toLower,-} toUpper)
 import Data.Function.Memoize (deriveMemoizable, memoize2)
 import Data.Maybe (fromMaybe)
-import Data.Version (showVersion, Version(Version))
+import Data.Version (showVersion, Version(Version), parseVersion)
+import Debian.Debianize.BinaryDebDescription (PackageType(..))
 import Debian.Relation (BinPkgName(BinPkgName))
 import Debian.Version (DebianVersion, parseDebianVersion)
-import Distribution.Compiler (CompilerId(CompilerId), CompilerFlavor(..))
-import System.Console.GetOpt
+import Distribution.Compiler (CompilerFlavor(..), CompilerId(CompilerId))
+#if MIN_VERSION_Cabal(1,22,0)
+import Distribution.Compiler (CompilerInfo(..), unknownCompilerInfo, AbiTag(NoAbiTag))
+#endif
+import System.Console.GetOpt (ArgDescr(ReqArg), OptDescr(..))
 import System.Directory (doesDirectoryExist)
+import System.Exit (ExitCode(ExitFailure))
 import System.IO.Unsafe (unsafePerformIO)
-import System.Process (readProcess)
-import System.Unix.Chroot (useEnv)
+import System.Process (readProcess, showCommandForUser, readProcessWithExitCode)
+import System.Unix.Chroot (useEnv, fchroot)
+import System.Unix.Mount (WithProcAndSys)
+import Text.ParserCombinators.ReadP (readP_to_S)
 import Text.Read (readMaybe)
 
 $(deriveMemoizable ''CompilerFlavor)
@@ -60,9 +72,8 @@ newestAvailable' root (BinPkgName name) = do
 
 newestAvailableCompiler :: FilePath -> CompilerFlavor -> DebianVersion
 newestAvailableCompiler root hc =
-    case debName hc of
-      Nothing -> error $ "newestAvailableCompiler - Unsupported CompilerFlavor: " ++ show hc
-      Just pkg -> fromMaybe (error $ "newestAvailableCompiler - No versions of " ++ show hc ++ " available in " ++ show root) (newestAvailable root pkg)
+    fromMaybe (error $ "newestAvailableCompiler - No versions of " ++ show hc ++ " available in " ++ show root)
+              (newestAvailable root (compilerPackageName hc Development))
 
 newestAvailableCompilerId :: FilePath -> CompilerFlavor -> CompilerId
 newestAvailableCompilerId root hc = compilerIdFromDebianVersion hc (newestAvailableCompiler root hc)
@@ -107,9 +118,6 @@ compilerIdFromDebianVersion :: CompilerFlavor -> DebianVersion -> CompilerId
 compilerIdFromDebianVersion hc debVersion =
     let (Version ds ts) = greatestLowerBound debVersion (map (\ d -> Version [d] []) [0..]) in
     CompilerId hc (greatestLowerBound debVersion (map (\ d -> Version (ds ++ [d]) ts) [0..]))
-#if MIN_VERSION_Cabal(1,21,0)
-               Nothing
-#endif
     where
       greatestLowerBound :: DebianVersion -> [Version] -> Version
       greatestLowerBound b xs = last $ takeWhile (\ v -> parseDebianVersion (showVersion v) < b) xs
@@ -127,8 +135,56 @@ compilerFlavorOption f =
       readHC :: String -> a -> a
       readHC s = maybe (error $ "Invalid CompilerFlavor: " ++ show s) f (readMaybe (map toUpper s))
 
+{-
 debName :: CompilerFlavor -> Maybe BinPkgName
 debName hc =
     case map toLower (show hc) of
       s | any isSpace s -> Nothing
       s -> Just (BinPkgName s)
+-}
+
+compilerPackageName :: CompilerFlavor -> PackageType -> BinPkgName
+compilerPackageName GHC Documentation = BinPkgName "ghc-doc" -- "ghc-7.10.1-htmldocs"
+compilerPackageName GHC Profiling = BinPkgName "ghc-prof" -- "ghc-7.10.1-prof"
+compilerPackageName GHC Development = BinPkgName "ghc" -- "ghc-7.10.1"
+compilerPackageName GHC _ = BinPkgName "ghc" -- "ghc-7.10.1" -- whatevs
+#if MIN_VERSION_Cabal(1,22,0)
+compilerPackageName GHCJS Documentation = BinPkgName "ghcjs"
+compilerPackageName GHCJS Profiling = error "Profiling not supported for GHCJS"
+compilerPackageName GHCJS Development = BinPkgName "ghcjs"
+compilerPackageName GHCJS _ = BinPkgName "ghcjs" -- whatevs
+#endif
+compilerPackageName x _ = error $ "Unsupported compiler flavor: " ++ show x
+
+#if MIN_VERSION_Cabal(1,22,0)
+-- | IO based alternative to newestAvailableCompilerId - install the
+-- compiler into the chroot if necessary and ask it for its version
+-- number.  This has the benefit of working for ghcjs, which doesn't
+-- make the base ghc version available in the version number.
+--
+-- Assumes the compiler executable is already installed in the root
+-- environment.
+getCompilerInfo :: MonadIO m => FilePath -> CompilerFlavor -> WithProcAndSys m CompilerInfo
+getCompilerInfo "/" flavor = liftIO $ getCompilerInfo' flavor
+getCompilerInfo root flavor = liftIO $ fchroot root $ getCompilerInfo' flavor
+
+getCompilerInfo' :: CompilerFlavor -> IO CompilerInfo
+getCompilerInfo' flavor = do
+    compilerId <- runVersionCommand >>= toCompilerId flavor
+    compilerCompat <- case flavor of
+                        GHCJS -> readProcessWithExitCode "ghcjs" ["--numeric-ghc-version"] "" >>= toCompilerId GHC >>= return . Just . (: [])
+                        _ -> return Nothing
+    return $ (unknownCompilerInfo compilerId NoAbiTag) {compilerInfoCompat = compilerCompat}
+    where
+      runVersionCommand :: IO (ExitCode, String, String)
+      runVersionCommand = readProcessWithExitCode versionCommand ["--numeric-version"] ""
+      versionCommand = case flavor of GHC -> "ghc"; GHCJS -> "ghcjs"; _ -> error $ "Flavor " ++ show flavor
+
+      toCompilerId :: CompilerFlavor -> (ExitCode, String, String) -> IO CompilerId
+      toCompilerId _ (ExitFailure n, _, err) =
+          error $ showCommandForUser versionCommand ["--numeric-version"] ++ " -> " ++ show n ++ ", stderr: " ++ show err
+      toCompilerId flavor' (_, out, _) =
+          case filter ((== "\n") . snd) (readP_to_S parseVersion out) of
+            [(v, _)] -> return $ CompilerId flavor' v
+            _ -> error $ "Parse failure for version string: " ++ show out
+#endif
