@@ -4,53 +4,54 @@ module Debian.Orphans where
 
 import Data.Function (on)
 import Data.Generics (Data, Typeable)
-import Data.List (isPrefixOf, intersperse)
+import Data.List (intersperse, isPrefixOf)
 import Data.Maybe (fromMaybe)
 import Data.Monoid ((<>))
-import Data.Version (Version(..), showVersion)
+import Data.Version (showVersion, Version(..))
 import Debian.Changes (ChangeLog(..), ChangeLogEntry(..))
-import Debian.Pretty (Pretty(pretty), text, cat, empty)
-import Debian.Relation (Relation(..), VersionReq(..), ArchitectureReq(..),
-                        SrcPkgName(..))
-import Debian.Version (DebianVersion)
+import Debian.Pretty (PP(PP, unPP))
+import Debian.Relation (ArchitectureReq(..), Relation(..), VersionReq(..))
 import Distribution.Compiler (CompilerId(..))
+#if MIN_VERSION_Cabal(1,22,0)
+import Distribution.Compiler (AbiTag(..))
+#endif
 #if !MIN_VERSION_Cabal(1,18,0)
 import Distribution.Compiler (CompilerFlavor(..))
 #endif
 import Distribution.License (License(..))
-import Distribution.PackageDescription (PackageDescription(package), Executable(..))
+import Distribution.PackageDescription (Executable(..), PackageDescription(package))
 import Distribution.Simple.Compiler (Compiler(..))
-import Distribution.Version (VersionRange(..), foldVersionRange')
-import Language.Haskell.Extension (Extension(..), KnownExtension(..), Language(..))
+import Distribution.Version (foldVersionRange', VersionRange(..))
+import Language.Haskell.Extension (Language(..))
+#if !MIN_VERSION_Cabal(1,21,0)
+import Language.Haskell.Extension (Extension(..), KnownExtension(..))
+#endif
+import Network.URI (URI)
 import Text.ParserCombinators.Parsec.Rfc2822 (NameAddr(..))
+import Text.PrettyPrint.HughesPJClass (hcat, Pretty(pPrint), text)
 
 deriving instance Typeable Compiler
 deriving instance Typeable CompilerId
 
-#if !MIN_VERSION_Cabal(1,18,0)
-deriving instance Typeable CompilerFlavor
-deriving instance Typeable Language
-deriving instance Typeable Extension
-deriving instance Typeable KnownExtension
+#if MIN_VERSION_Cabal(1,22,0)
+deriving instance Typeable AbiTag
+deriving instance Data AbiTag
+deriving instance Eq AbiTag
+deriving instance Ord AbiTag
 #endif
 
 deriving instance Data Compiler
 deriving instance Data CompilerId
 
-#if !MIN_VERSION_Cabal(1,18,0)
-deriving instance Data Extension
-deriving instance Data KnownExtension
-deriving instance Data Language
-deriving instance Data CompilerFlavor
-#endif
-
 deriving instance Ord Language
-deriving instance Ord KnownExtension
-deriving instance Ord Extension
 deriving instance Eq Compiler
 deriving instance Ord Compiler
 deriving instance Ord NameAddr
 deriving instance Ord License
+#if !MIN_VERSION_Cabal(1,21,1)
+deriving instance Ord KnownExtension
+deriving instance Ord Extension
+#endif
 
 instance Ord Executable where
     compare = compare `on` exeName
@@ -77,24 +78,27 @@ deriving instance Ord ChangeLog
 deriving instance Ord ChangeLogEntry
 
 #if !MIN_VERSION_Cabal(1,18,0)
-deriving instance Typeable License
+deriving instance Data CompilerFlavor
+deriving instance Data Language
 deriving instance Data Version
-deriving instance Data License
+deriving instance Typeable CompilerFlavor
+deriving instance Typeable Extension
+deriving instance Typeable Language
 #endif
 
 -- Convert from license to RPM-friendly description.  The strings are
 -- taken from TagsCheck.py in the rpmlint distribution.
-instance Pretty License where
-    pretty (GPL _) = text "GPL"
-    pretty (LGPL _) = text "LGPL"
-    pretty BSD3 = text "BSD"
-    pretty BSD4 = text "BSD-like"
-    pretty PublicDomain = text "Public Domain"
-    pretty AllRightsReserved = text "Proprietary"
-    pretty OtherLicense = text "Non-distributable"
-    pretty MIT = text "MIT"
-    pretty (UnknownLicense _) = text "Unknown"
-    pretty x = pretty (show x)
+instance Pretty (PP License) where
+    pPrint (PP (GPL _)) = text "GPL"
+    pPrint (PP (LGPL _)) = text "LGPL"
+    pPrint (PP BSD3) = text "BSD"
+    pPrint (PP BSD4) = text "BSD-like"
+    pPrint (PP PublicDomain) = text "Public Domain"
+    pPrint (PP AllRightsReserved) = text "Proprietary"
+    pPrint (PP OtherLicense) = text "Non-distributable"
+    pPrint (PP MIT) = text "MIT"
+    pPrint (PP (UnknownLicense _)) = text "Unknown"
+    pPrint (PP x) = text (show x)
 
 deriving instance Data NameAddr
 deriving instance Typeable NameAddr
@@ -103,41 +107,30 @@ deriving instance Read NameAddr
 -- This Pretty instance gives a string used to create a valid
 -- changelog entry, it *must* have a name followed by an email address
 -- in angle brackets.
-instance Pretty NameAddr where
-    pretty x = pretty (fromMaybe (nameAddr_addr x) (nameAddr_name x) ++ " <" ++ nameAddr_addr x ++ ">")
-    -- pretty x = text (maybe (nameAddr_addr x) (\ n -> n ++ " <" ++ nameAddr_addr x ++ ">") (nameAddr_name x))
+instance Pretty (PP NameAddr) where
+    pPrint (PP x) = text (fromMaybe (nameAddr_addr x) (nameAddr_name x) ++ " <" ++ nameAddr_addr x ++ ">")
+    -- pPrint x = text (maybe (nameAddr_addr x) (\ n -> n ++ " <" ++ nameAddr_addr x ++ ">") (nameAddr_name x))
 
-instance Pretty [NameAddr] where
-    pretty = cat . intersperse (text ", ") . map pretty
+instance Pretty (PP [NameAddr]) where
+    pPrint = hcat . intersperse (text ", ") . map (pPrint . PP) . unPP
 
-instance Pretty (Maybe NameAddr) where
-    pretty Nothing = empty
-    pretty (Just x) = pretty x
-
-instance Pretty VersionRange where
-    pretty range =
+instance Pretty (PP VersionRange) where
+    pPrint (PP range) =
         foldVersionRange'
           (text "*")
-          (\ v -> text "=" <> pretty v)
-          (\ v -> text ">" <> pretty v)
-          (\ v -> text "<" <> pretty v)
-          (\ v -> text ">=" <> pretty v)
-          (\ v -> text "<=" <> pretty v)
-          (\ x _ -> text "=" <> pretty x <> text ".*") -- not exactly right
+          (\ v -> text "=" <> pPrint (PP v))
+          (\ v -> text ">" <> pPrint (PP v))
+          (\ v -> text "<" <> pPrint (PP v))
+          (\ v -> text ">=" <> pPrint (PP v))
+          (\ v -> text "<=" <> pPrint (PP v))
+          (\ x _ -> text "=" <> pPrint (PP x) <> text ".*") -- not exactly right
           (\ x y -> text "(" <> x <> text " || " <> y <> text ")")
           (\ x y -> text "(" <> x <> text " && " <> y <> text ")")
           (\ x -> text "(" <> x <> text ")")
           range
 
-instance Pretty Version where
-    pretty = pretty . showVersion
+instance Pretty (PP Version) where
+    pPrint = text . showVersion . unPP
 
-instance Pretty DebianVersion where
-    pretty = pretty . show
-
-instance Pretty (Maybe SrcPkgName) where
-    pretty Nothing = empty
-    pretty (Just x) = pretty x
-
-instance Pretty Bool where
-    pretty = pretty . show
+instance Pretty (PP URI) where
+    pPrint = text . show . unPP
