@@ -29,6 +29,8 @@ module Debian.Policy
     , parsePackageArchitectures
     , Section(..)
     , readSection
+    , MultiArch(..)
+    , readMultiArch
     , Area(..)
     , parseUploaders
     , parseMaintainer
@@ -216,6 +218,24 @@ instance Pretty (PP Section) where
     pPrint (PP (MainSection sec)) = text sec
     pPrint (PP (AreaSection area sec)) = pPrint (PP area) <> text "/" <> text sec
 
+data MultiArch = MANo | MASame | MAForeign | MAAllowed
+    deriving (Read, Eq, Ord, Show, Data, Typeable)
+
+readMultiArch :: String -> MultiArch
+readMultiArch s =
+    case unpack (strip (pack s)) of
+      "no" -> MANo
+      "same" -> MASame
+      "foreign" -> MAForeign
+      "allowed" -> MAAllowed
+      x -> error $ "Invalid Multi-Arch string: " ++ show x
+
+instance Pretty (PP MultiArch) where
+    pPrint (PP MANo) = text "no"
+    pPrint (PP MASame) = text "same"
+    pPrint (PP MAForeign) = text "foreign"
+    pPrint (PP MAAllowed) = text "allowed"
+
 -- Is this really all that is allowed here?  Doesn't Ubuntu have different areas?
 data Area
     = Main
@@ -333,8 +353,7 @@ data License
     | Zlib              -- ^ zlib/libpng license.
     | Zope              -- ^ Zope Public License 1.0, 1.1, 2.0, 2.1.
     | OtherLicense String
-                        -- ^ A license name associated with the subsequent text of the License: field or in
-                        -- a Files paragraph of the same debian/copyright file, or in a License: paragraph.
+                        -- ^ Any other license name
     deriving (Read, Show, Eq, Ord, Data, Typeable)
 
 -- We need a license parse function that converts these strings back
