@@ -7,7 +7,8 @@ import Data.Monoid (mempty)
 import Data.Set as Set (singleton, insert)
 import Data.Text as Text (intercalate)
 import Debian.Changes (ChangeLog(..))
-import Debian.Debianize -- (debianize, doBackups, doExecutable, doServer, doWebsite, inputChangeLog, inputDebianization, debianDefaultAtoms)
+import Debian.Debianize
+import Debian.Debianize.Finalize (debianize)
 import Debian.Debianize.Optparse (parseProgramArguments, CommandLineOptions(..))
 import Debian.Pretty (ppShow)
 import Debian.Policy (databaseDirectory, PackageArchitectures(All), StandardsVersion(StandardsVersion))
@@ -26,7 +27,7 @@ main =
        old <- withCurrentDirectory "test-data/artvaluereport2/output" $ parseProgramArguments >>= \opts -> execDebianT inputDebianization (makeDebInfo (_flags opts))
        -- The newest log entry gets modified when the Debianization is
        -- generated, it won't match so drop it for the comparison.
-       compareDebianization old ({-copyFirstLogEntry old $ -} view debInfo new) >>= putStr
+       putStr $ concat $ compareDebianization old $ view debInfo new
     where
       customize :: Maybe ChangeLog -> CabalT IO ()
       customize log =
